// Navigation links
export const navLinks = [
  { href: '#how-it-works', label: 'How It Works' },
  { href: '#collaboration', label: 'Collaboration' },
  { href: '#features', label: 'Features' },
  { href: '#why-it-matters', label: 'Why It Matters' },
  { href: '#pricing', label: 'Pricing' },
]

// Footer links
export const footerLinks = {
  product: [
    { href: '#features', label: 'Features' },
    { href: '#pricing', label: 'Pricing' },
    { href: '/docs', label: 'Documentation' },
  ],
  company: [
    { href: '/about', label: 'About' },
    { href: '/blog', label: 'Blog' },
    { href: '/careers', label: 'Careers' },
  ],
  support: [
    { href: '/contact', label: 'Contact' },
    { href: '/help', label: 'Help Center' },
    { href: '/status', label: 'Status' },
  ],
}

// Stats data - Matrix protocol that MindRoom is built on
export const stats = [
  { value: '115M', label: 'Users on Matrix Protocol', suffix: '+' },
  { value: '150K', label: 'Orgs Trust Matrix Security', suffix: '+' },
  { value: '10', label: 'Years of Matrix Development', suffix: '+' },
  { value: '€30M', label: 'Invested in Matrix Foundation', suffix: '+' },
]

// Trust organizations - Real Matrix users
export const trustCompanies = ['German Healthcare', 'French Government', 'NATO', 'U.S. Space Force', 'Matrix Foundation']
