"""Backend package for the MindRoom platform.

This package contains configuration, shared dependencies, and route modules
that are included by the FastAPI application in `platform-backend/main.py`.
"""
